package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcDeclare;

/**
 * 工作填报Mapper接口
 * 
 * @author cmc
 * @date 2024-08-14
 */
public interface CmcDeclareMapper 
{
    /**
     * 查询工作填报
     * 
     * @param formId 工作填报主键
     * @return 工作填报
     */
    public CmcDeclare selectCmcDeclareByFormId(String formId);

    /**
     * 查询工作填报列表
     * 
     * @param cmcDeclare 工作填报
     * @return 工作填报集合
     */
    public List<CmcDeclare> selectCmcDeclareList(CmcDeclare cmcDeclare);

    /**
     * 新增工作填报
     * 
     * @param cmcDeclare 工作填报
     * @return 结果
     */
    public int insertCmcDeclare(CmcDeclare cmcDeclare);

    /**
     * 修改工作填报
     * 
     * @param cmcDeclare 工作填报
     * @return 结果
     */
    public int updateCmcDeclare(CmcDeclare cmcDeclare);

    /**
     * 删除工作填报
     * 
     * @param formId 工作填报主键
     * @return 结果
     */
    public int deleteCmcDeclareByFormId(String formId);

    /**
     * 批量删除工作填报
     * 
     * @param formIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcDeclareByFormIds(String[] formIds);
}
